timeintervaltools.shift_aggregate_offset_to_rational
====================================================

.. autofunction:: abjad.tools.timeintervaltools.shift_aggregate_offset_to_rational.shift_aggregate_offset_to_rational
